@@ -14,6 +14,8 @@ macro_rules! autoclap {
                 env!("CARGO_PKG_VERSION"),
             )
         ))
+        .author(env!("CARGO_PKG_AUTHORS"))
+        .about(env!("CARGO_PKG_DESCRIPTION"))
         .arg(
             Arg::new("debug")
                 .long("debug")
@@ -32,7 +34,7 @@ mod tests {
         let app = autoclap!();
         assert_eq!(
             app.get_name(),
-            "autoclap 0.1.1 :: https://github.com/mihaigalos/autoclap/releases/tag/0.1.1"
+            "autoclap 0.1.2 :: https://github.com/mihaigalos/autoclap/releases/tag/0.1.2"
         );
     }
     #[test]
